pub struct Subordinate {
pub issuer: Name,
pub subject: Name,
pub path_len_constraint: Option<u8>,
pub emits_ocsp_response: bool,
pub client_auth: bool,
}Expand description
TLS Subordinate CA Certificate Profile
BR 7.1.2.6 TLS Subordinate CA Certificate Profile
Fields
issuer: Nameissuer Name, represents the name signing the certificate
subject: Namesubject Name, represents the name of the newly issued certificated
path_len_constraint: Option<u8>pathLenConstraint INTEGER (0..MAX) OPTIONAL BasicConstraints as defined in [RFC 5280 Section 4.2.1.9].
emits_ocsp_response: boolemits_ocsp_response will append the KeyUsages::DigitalSignature. This is meant for
CAs that will reply to OCSP requests.
client_auth: boolAllows this subordinate CA to issue certificates capable of doing client authentication