This is unreleased documentation for the main (development) branch of crypto-glue.

Subscriber

Struct Subscriber 

pub struct Subscriber {
    pub certificate_type: CertificateType,
    pub issuer: Name,
    pub client_auth: bool,
    pub tls12_options: Tls12Options,
    pub enable_data_encipherment: bool,
}
7.1.2.7 Subscriber (Server) Certificate Profile

Fields

certificate_type: CertificateType

Subtype of the Subscriber Certificate Profile

issuer: Name

issuer Name, represents the name signing the certificate

client_auth: bool

Enable client authentication with the newly issued certificate

tls12_options: Tls12Options

TLS1.2 specific flags

It is only available under the hazmat feature flag.

enable_data_encipherment: bool

Enable dataEncipherment bit on KeyUsage. This bit is not recommended and is Pending Prohibition.

It is only available under the hazmat feature flag.