pub struct Subscriber {
pub certificate_type: CertificateType,
pub issuer: Name,
pub client_auth: bool,
pub tls12_options: Tls12Options,
pub enable_data_encipherment: bool,
}Expand description
7.1.2.7 Subscriber (Server) Certificate Profile
Fields
certificate_type: CertificateTypeSubtype of the Subscriber Certificate Profile
issuer: Nameissuer Name, represents the name signing the certificate
client_auth: boolEnable client authentication with the newly issued certificate
tls12_options: Tls12OptionsTLS1.2 specific flags
It is only available under the hazmat feature flag.
enable_data_encipherment: boolEnable dataEncipherment bit on KeyUsage.
This bit is not recommended and is Pending Prohibition.
It is only available under the hazmat feature flag.