pub struct Tls12Options {
pub enable_key_encipherment: bool,
pub enable_key_agreement: bool,
}Expand description
Tls12Options stores the KeyUsage bits that are required by specific uses of TLS1.2.
This specifically refers to the section 7.4.2 of RFC 5246:
RSA RSA public key; the certificate MUST allow the
RSA_PSK key to be used for encryption (the
keyEncipherment bit MUST be set if the key
usage extension is present).
Note: RSA_PSK is defined in [TLSPSK].
[...]
DH_DSS Diffie-Hellman public key; the keyAgreement bit
DH_RSA MUST be set if the key usage extension is
present.Those are meant for consumers relying on non-DH schemes with RSA keys and non-ECDH schemes with ECC keys.
This behavior is no longer provided by TLS 1.3 and is NOT RECOMMENDED by CABF as it is
Pending Prohibition.
Fields
enable_key_encipherment: boolEnable keyEncipherment on RSA keys.
enable_key_agreement: boolEnable keyAgreement on ECC keys.